==> flutter_nearby_messages_api-0.0.1.tar.gz: android/src/main/java/vn/tmhtechlab/flutter_nearby_messages_api/FlutterNearbyMessagesApiPlugin.java <==
package vn.tmhtechlab.flutter_nearby_messages_api;

import androidx.annotation.NonNull;
import android.app.Activity;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.provider.Settings;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import android.util.Log;

import com.google.android.gms.nearby.Nearby;
import com.google.android.gms.nearby.messages.Message;
import com.google.android.gms.nearby.messages.MessageListener;
import com.google.android.gms.nearby.messages.PublishOptions;
import com.google.android.gms.nearby.messages.Strategy;
import com.google.android.gms.nearby.messages.SubscribeOptions;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import static android.content.ContentValues.TAG;

public class FlutterNearbyMessagesApiPlugin extends BroadcastReceiver implements MethodCallHandler {
  private final Activity activity;
  private final Registrar registrar;
  private MethodChannel channel;
  private Message mActiveMessage;
  private PendingIntent pendingIntent;
  private MessageListener mMessageListener;

  /**
   * set up the broadcast receiver and nearby message listener
   * 
   * @param activity
   * @param registrar
   * @param methodChannel
   */
  private FlutterNearbyMessagesApiPlugin(Activity activity, Registrar registrar, MethodChannel methodChannel) {

    mMessageListener = new MessageListener() {
      @Override
      public void onFound(Message message) {
        channel.invokeMethod("onFound", new String(message.getContent()));
      }

      @Override
      public void onLost(Message message) {
        channel.invokeMethod("onLost", new String(message.getContent()));
      }
    };

    this.activity = activity;
    this.registrar = registrar;
    this.channel = methodChannel;

    LocalBroadcastManager manager = LocalBroadcastManager.getInstance(registrar.context());
    manager.registerReceiver(this, new IntentFilter());
  }

  /**
   * Plugin registration.
   */
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_nearby_messages_api");
    final FlutterNearbyMessagesApiPlugin plugin = new FlutterNearbyMessagesApiPlugin(registrar.activity(), registrar,
        channel);
    channel.setMethodCallHandler(plugin);
  }

  /**
   * attache the nearby messages listener to a broadcast receiver background
   * service can pass messages to the host this way
   * 
   * @param context
   * @param intent
   */
  @Override
  public void onReceive(Context context, Intent intent) {
    Nearby.getMessagesClient(context).handleIntent(intent, new MessageListener() {
      @Override
      public void onFound(Message message) {
        Log.i(TAG, "Found message via PendingIntent: " + message);
        String messageContent = new String(message.getContent());
        channel.invokeMethod("onFound", messageContent);
      }

      @Override
      public void onLost(Message message) {
        Log.i(TAG, "Lost message via PendingIntent: " + message);
        String messageContent = new String(message.getContent());
        channel.invokeMethod("onLost", messageContent);
      }
    });
  }

  /**
   * background receiver subscription
   */
  void backgroundSubscribe() {
    Log.i(TAG, "Subscribing for background updates.");

    SubscribeOptions options = new SubscribeOptions.Builder().setStrategy(Strategy.DEFAULT).build();
    Nearby.getMessagesClient(activity).subscribe(mMessageListener, options);
  }

  /**
   * unsubscribe from broadcast receiver
   */
  void backgroundUnsubscribe() {
    Nearby.getMessagesClient(activity).unsubscribe(getPendingIntent());
    pendingIntent = null;
  }

  /**
   * makes this class a pending intent for the broadcast receiver
   * 
   * @return
   */
  private PendingIntent getPendingIntent() {
    if (pendingIntent == null) {
      pendingIntent = PendingIntent.getBroadcast(activity, 0,
          new Intent(activity, FlutterNearbyMessagesApiPlugin.class), PendingIntent.FLAG_UPDATE_CURRENT);

    }
    return pendingIntent;
  }

  void publish(String message) {
    unPublish();

    mActiveMessage = new Message(message.getBytes());
    Strategy strategy = new Strategy.Builder().setTtlSeconds(Strategy.TTL_SECONDS_DEFAULT)
        .setDiscoveryMode(Strategy.DISCOVERY_MODE_SCAN).build();
    PublishOptions options = new PublishOptions.Builder().setStrategy(strategy).build();
    Nearby.getMessagesClient(activity).publish(mActiveMessage, options);
  }

  void unPublish() {
    if (mActiveMessage != null) {
      Nearby.getMessagesClient(activity).unpublish(mActiveMessage);
      mActiveMessage = null;
    }
  }

  /**
   * Host will invoke these methods to set up the nearby messages API listener
   * 
   * @param call
   * @param result
   */
  @Override
  public void onMethodCall(MethodCall call, Result result) {
    switch (call.method) {
      case "setAPIKey":
        Log.i(TAG,
            "~~~ Only on iOS. Please reference https://developers.google.com/nearby/messages/android/get-started");

        result.success(null);
        break;
      case "backgroundSubscribe":
        this.backgroundSubscribe();
        result.success(null);
        break;
      case "backgroundUnsubscribe":
        this.backgroundUnsubscribe();
        result.success(null);
        break;
      case "publish":
        final String message = call.argument("message");

        Log.i(TAG, "Message is: " + message);
        this.publish(message);
        result.success(null);
        break;
      case "unPublish":
        this.unPublish();
        result.success(null);
        break;
      case "setGranted":
        Log.i(TAG, "~~~ setGranted: Only on iOS");
        result.success(null);
        break;
      case "enableDebugMode":
        Log.i(TAG, "~~~ enableDebugMode: Available on iOS. Android is TODO");
        result.success(null);
        break;
      case "disableDebugMode":
        Log.i(TAG, "~~~ disableDebugMode: Available on iOS. Android is TODO");
        result.success(null);
        break;
      default:
        result.notImplemented();
    }
  }
}

==> flutter_nearby_messages_api-0.0.2.tar.gz: android/src/main/java/vn/tmhtechlab/flutter_nearby_messages_api/FlutterNearbyMessagesApiPlugin.java <==
package vn.tmhtechlab.flutter_nearby_messages_api;

import androidx.annotation.NonNull;
import android.app.Activity;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.provider.Settings;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import android.util.Log;

import com.google.android.gms.nearby.Nearby;
import com.google.android.gms.nearby.messages.Message;
import com.google.android.gms.nearby.messages.MessageListener;
import com.google.android.gms.nearby.messages.PublishOptions;
import com.google.android.gms.nearby.messages.Strategy;
import com.google.android.gms.nearby.messages.SubscribeOptions;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;

import static android.content.ContentValues.TAG;

public class FlutterNearbyMessagesApiPlugin extends BroadcastReceiver
    implements FlutterPlugin, MethodCallHandler, ActivityAware {
  private Activity activity;
  private MethodChannel channel;
  private Message mActiveMessage;
  private PendingIntent pendingIntent;
  private MessageListener mMessageListener;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding binding) {
    channel = new MethodChannel(binding.getBinaryMessenger(), "flutter_nearby_messages_api");
    channel.setMethodCallHandler(this);

    mMessageListener = new MessageListener() {
      @Override
      public void onFound(Message message) {
        channel.invokeMethod("onFound", new String(message.getContent()));
      }

      @Override
      public void onLost(Message message) {
        channel.invokeMethod("onLost", new String(message.getContent()));
      }
    };
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    // TODO: your plugin is no longer attached to a Flutter experience.
  }

  /**
   * attache the nearby messages listener to a broadcast receiver background
   * service can pass messages to the host this way
   * 
   * @param context
   * @param intent
   */
  @Override
  public void onReceive(Context context, Intent intent) {
    Nearby.getMessagesClient(context).handleIntent(intent, new MessageListener() {
      @Override
      public void onFound(Message message) {
        Log.i(TAG, "Found message via PendingIntent: " + message);
        String messageContent = new String(message.getContent());
        channel.invokeMethod("onFound", messageContent);
      }

      @Override
      public void onLost(Message message) {
        Log.i(TAG, "Lost message via PendingIntent: " + message);
        String messageContent = new String(message.getContent());
        channel.invokeMethod("onLost", messageContent);
      }
    });
  }

  /**
   * background receiver subscription
   */
  void backgroundSubscribe() {
    Log.i(TAG, "Subscribing for background updates.");

    SubscribeOptions options = new SubscribeOptions.Builder().setStrategy(Strategy.DEFAULT).build();
    Nearby.getMessagesClient(activity).subscribe(mMessageListener, options);
  }

  /**
   * unsubscribe from broadcast receiver
   */
  void backgroundUnsubscribe() {
    Nearby.getMessagesClient(activity).unsubscribe(getPendingIntent());
    pendingIntent = null;
  }

  /**
   * makes this class a pending intent for the broadcast receiver
   * 
   * @return
   */
  private PendingIntent getPendingIntent() {
    if (pendingIntent == null) {
      pendingIntent = PendingIntent.getBroadcast(activity, 0,
          new Intent(activity, FlutterNearbyMessagesApiPlugin.class), PendingIntent.FLAG_UPDATE_CURRENT);

    }
    return pendingIntent;
  }

  void publish(String message) {
    unPublish();

    mActiveMessage = new Message(message.getBytes());
    Strategy strategy = new Strategy.Builder().setTtlSeconds(Strategy.TTL_SECONDS_DEFAULT)
        .setDiscoveryMode(Strategy.DISCOVERY_MODE_SCAN).build();
    PublishOptions options = new PublishOptions.Builder().setStrategy(strategy).build();
    Nearby.getMessagesClient(activity).publish(mActiveMessage, options);
  }

  void unPublish() {
    if (mActiveMessage != null) {
      Nearby.getMessagesClient(activity).unpublish(mActiveMessage);
      mActiveMessage = null;
    }
  }

  @Override
  public void onAttachedToActivity(ActivityPluginBinding binding) {
    activity = binding.getActivity();
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {
    // TODO
  }

  @Override
  public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding) {
    // TODO
  }

  @Override
  public void onDetachedFromActivity() {
    // TODO
  }

  /**
   * Host will invoke these methods to set up the nearby messages API listener
   * 
   * @param call
   * @param result
   */
  @Override
  public void onMethodCall(MethodCall call, Result result) {
    switch (call.method) {
      case "setAPIKey":
        Log.i(TAG,
            "~~~ Only on iOS. Please reference https://developers.google.com/nearby/messages/android/get-started");

        result.success(null);
        break;
      case "backgroundSubscribe":
        this.backgroundSubscribe();
        result.success(null);
        break;
      case "backgroundUnsubscribe":
        this.backgroundUnsubscribe();
        result.success(null);
        break;
      case "publish":
        final String message = call.argument("message");

        Log.i(TAG, "Message is: " + message);
        this.publish(message);
        result.success(null);
        break;
      case "unPublish":
        this.unPublish();
        result.success(null);
        break;
      case "setGranted":
        Log.i(TAG, "~~~ setGranted: Only on iOS");
        result.success(null);
        break;
      case "enableDebugMode":
        Log.i(TAG, "~~~ enableDebugMode: Available on iOS. Android is TODO");
        result.success(null);
        break;
      case "disableDebugMode":
        Log.i(TAG, "~~~ disableDebugMode: Available on iOS. Android is TODO");
        result.success(null);
        break;
      default:
        result.notImplemented();
    }
  }
}
